==> org.eclipse.emf.parsley.dsl.ui.source_1.0.1.v20160706-1123.jar: org/eclipse/emf/parsley/dsl/ui/labeling/EmfParsleyDslLabelProvider.java <==
/**
 * Copyright (c) 2013 RCP Vision (http://www.rcp-vision.com) and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 * Lorenzo Bettini - initial API and implementation
 */
package org.eclipse.emf.parsley.dsl.ui.labeling;

import com.google.inject.Inject;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.edit.ui.provider.AdapterFactoryLabelProvider;
import org.eclipse.emf.parsley.dsl.model.BindingsSpecification;
import org.eclipse.emf.parsley.dsl.model.Configurator;
import org.eclipse.emf.parsley.dsl.model.DialogControlFactory;
import org.eclipse.emf.parsley.dsl.model.DialogFeatureCaptionProvider;
import org.eclipse.emf.parsley.dsl.model.FeatureCaptionProvider;
import org.eclipse.emf.parsley.dsl.model.FeaturesProvider;
import org.eclipse.emf.parsley.dsl.model.FormControlFactory;
import org.eclipse.emf.parsley.dsl.model.FormFeatureCaptionProvider;
import org.eclipse.emf.parsley.dsl.model.LabelProvider;
import org.eclipse.emf.parsley.dsl.model.MenuBuilder;
import org.eclipse.emf.parsley.dsl.model.PartsSpecifications;
import org.eclipse.emf.parsley.dsl.model.ProposalCreator;
import org.eclipse.emf.parsley.dsl.model.ResourceManager;
import org.eclipse.emf.parsley.dsl.model.TableFeaturesProvider;
import org.eclipse.emf.parsley.dsl.model.TableLabelProvider;
import org.eclipse.emf.parsley.dsl.model.TableViewerContentProvider;
import org.eclipse.emf.parsley.dsl.model.ViewerContentProvider;
import org.eclipse.emf.parsley.dsl.services.EmfParsleyDslGrammarAccess;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.xtext.Keyword;
import org.eclipse.xtext.common.types.JvmVisibility;
import org.eclipse.xtext.xbase.ui.labeling.XbaseImages2;
import org.eclipse.xtext.xbase.ui.labeling.XbaseLabelProvider;

/**
 * Provides labels for a EObjects.
 * 
 * see http://www.eclipse.org/Xtext/documentation.html#labelProvider
 */
@SuppressWarnings("all")
public class EmfParsleyDslLabelProvider extends XbaseLabelProvider {
  @Inject
  private EmfParsleyDslGrammarAccess g;
  
  @Inject
  private XbaseImages2 images;
  
  @Inject
  public EmfParsleyDslLabelProvider(final AdapterFactoryLabelProvider delegate) {
    super(delegate);
  }
  
  public String text(final BindingsSpecification e) {
    EmfParsleyDslGrammarAccess.BindingsSpecificationElements _bindingsSpecificationAccess = this.g.getBindingsSpecificationAccess();
    Keyword _bindingsKeyword_1 = _bindingsSpecificationAccess.getBindingsKeyword_1();
    return _bindingsKeyword_1.getValue();
  }
  
  public String text(final LabelProvider e) {
    EmfParsleyDslGrammarAccess.LabelProviderElements _labelProviderAccess = this.g.getLabelProviderAccess();
    Keyword _labelProviderKeyword_1 = _labelProviderAccess.getLabelProviderKeyword_1();
    return _labelProviderKeyword_1.getValue();
  }
  
  public String text(final TableLabelProvider e) {
    EmfParsleyDslGrammarAccess.TableLabelProviderElements _tableLabelProviderAccess = this.g.getTableLabelProviderAccess();
    Keyword _tableLabelProviderKeyword_1 = _tableLabelProviderAccess.getTableLabelProviderKeyword_1();
    return _tableLabelProviderKeyword_1.getValue();
  }
  
  public String text(final FeatureCaptionProvider e) {
    EmfParsleyDslGrammarAccess.FeatureCaptionProviderElements _featureCaptionProviderAccess = this.g.getFeatureCaptionProviderAccess();
    Keyword _featureCaptionProviderKeyword_1 = _featureCaptionProviderAccess.getFeatureCaptionProviderKeyword_1();
    return _featureCaptionProviderKeyword_1.getValue();
  }
  
  public String text(final FormFeatureCaptionProvider e) {
    EmfParsleyDslGrammarAccess.FormFeatureCaptionProviderElements _formFeatureCaptionProviderAccess = this.g.getFormFeatureCaptionProviderAccess();
    Keyword _formFeatureCaptionProviderKeyword_1 = _formFeatureCaptionProviderAccess.getFormFeatureCaptionProviderKeyword_1();
    return _formFeatureCaptionProviderKeyword_1.getValue();
  }
  
  public String text(final DialogFeatureCaptionProvider e) {
    EmfParsleyDslGrammarAccess.DialogFeatureCaptionProviderElements _dialogFeatureCaptionProviderAccess = this.g.getDialogFeatureCaptionProviderAccess();
    Keyword _dialogFeatureCaptionProviderKeyword_1 = _dialogFeatureCaptionProviderAccess.getDialogFeatureCaptionProviderKeyword_1();
    return _dialogFeatureCaptionProviderKeyword_1.getValue();
  }
  
  public String text(final FeaturesProvider e) {
    EmfParsleyDslGrammarAccess.FeaturesProviderElements _featuresProviderAccess = this.g.getFeaturesProviderAccess();
    Keyword _featuresProviderKeyword_1 = _featuresProviderAccess.getFeaturesProviderKeyword_1();
    return _featuresProviderKeyword_1.getValue();
  }
  
  public String text(final TableFeaturesProvider e) {
    EmfParsleyDslGrammarAccess.TableFeaturesProviderElements _tableFeaturesProviderAccess = this.g.getTableFeaturesProviderAccess();
    Keyword _tableFeaturesProviderKeyword_1 = _tableFeaturesProviderAccess.getTableFeaturesProviderKeyword_1();
    return _tableFeaturesProviderKeyword_1.getValue();
  }
  
  public String text(final FormControlFactory e) {
    EmfParsleyDslGrammarAccess.FormControlFactoryElements _formControlFactoryAccess = this.g.getFormControlFactoryAccess();
    Keyword _formControlFactoryKeyword_1 = _formControlFactoryAccess.getFormControlFactoryKeyword_1();
    return _formControlFactoryKeyword_1.getValue();
  }
  
  public String text(final DialogControlFactory e) {
    EmfParsleyDslGrammarAccess.DialogControlFactoryElements _dialogControlFactoryAccess = this.g.getDialogControlFactoryAccess();
    Keyword _dialogControlFactoryKeyword_1 = _dialogControlFactoryAccess.getDialogControlFactoryKeyword_1();
    return _dialogControlFactoryKeyword_1.getValue();
  }
  
  public String text(final ProposalCreator e) {
    EmfParsleyDslGrammarAccess.ProposalCreatorElements _proposalCreatorAccess = this.g.getProposalCreatorAccess();
    Keyword _proposalsKeyword_1 = _proposalCreatorAccess.getProposalsKeyword_1();
    return _proposalsKeyword_1.getValue();
  }
  
  public String text(final MenuBuilder e) {
    EmfParsleyDslGrammarAccess.MenuBuilderElements _menuBuilderAccess = this.g.getMenuBuilderAccess();
    Keyword _menuBuilderKeyword_1 = _menuBuilderAccess.getMenuBuilderKeyword_1();
    return _menuBuilderKeyword_1.getValue();
  }
  
  public String text(final Configurator e) {
    EmfParsleyDslGrammarAccess.ConfiguratorElements _configuratorAccess = this.g.getConfiguratorAccess();
    Keyword _configuratorKeyword_1 = _configuratorAccess.getConfiguratorKeyword_1();
    return _configuratorKeyword_1.getValue();
  }
  
  public String text(final ViewerContentProvider e) {
    EmfParsleyDslGrammarAccess.ViewerContentProviderElements _viewerContentProviderAccess = this.g.getViewerContentProviderAccess();
    Keyword _viewerContentProviderKeyword_1 = _viewerContentProviderAccess.getViewerContentProviderKeyword_1();
    return _viewerContentProviderKeyword_1.getValue();
  }
  
  public String text(final TableViewerContentProvider e) {
    EmfParsleyDslGrammarAccess.TableViewerContentProviderElements _tableViewerContentProviderAccess = this.g.getTableViewerContentProviderAccess();
    Keyword _tableViewerContentProviderKeyword_1 = _tableViewerContentProviderAccess.getTableViewerContentProviderKeyword_1();
    return _tableViewerContentProviderKeyword_1.getValue();
  }
  
  public String text(final PartsSpecifications e) {
    EmfParsleyDslGrammarAccess.PartsSpecificationsElements _partsSpecificationsAccess = this.g.getPartsSpecificationsAccess();
    Keyword _partsKeyword_1 = _partsSpecificationsAccess.getPartsKeyword_1();
    return _partsKeyword_1.getValue();
  }
  
  public String text(final ResourceManager e) {
    EmfParsleyDslGrammarAccess.ResourceManagerElements _resourceManagerAccess = this.g.getResourceManagerAccess();
    Keyword _resourceManagerKeyword_1 = _resourceManagerAccess.getResourceManagerKeyword_1();
    return _resourceManagerKeyword_1.getValue();
  }
  
  public ImageDescriptor image(final EObject e) {
    return this.images.forClass(JvmVisibility.PUBLIC, 0);
  }
}

==> org.eclipse.emf.parsley.dsl.ui.source_1.11.0.v20200424-1436.jar: org/eclipse/emf/parsley/dsl/ui/labeling/EmfParsleyDslLabelProvider.java <==
/**
 * Copyright (c) 2013 RCP Vision (http://www.rcp-vision.com) and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 * Lorenzo Bettini - initial API and implementation
 */
package org.eclipse.emf.parsley.dsl.ui.labeling;

import com.google.inject.Inject;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.edit.ui.provider.AdapterFactoryLabelProvider;
import org.eclipse.emf.parsley.dsl.model.BindingsSpecification;
import org.eclipse.emf.parsley.dsl.model.Configurator;
import org.eclipse.emf.parsley.dsl.model.DialogControlFactory;
import org.eclipse.emf.parsley.dsl.model.DialogFeatureCaptionProvider;
import org.eclipse.emf.parsley.dsl.model.FeatureCaptionProvider;
import org.eclipse.emf.parsley.dsl.model.FeaturesProvider;
import org.eclipse.emf.parsley.dsl.model.FormControlFactory;
import org.eclipse.emf.parsley.dsl.model.FormFeatureCaptionProvider;
import org.eclipse.emf.parsley.dsl.model.LabelProvider;
import org.eclipse.emf.parsley.dsl.model.MenuBuilder;
import org.eclipse.emf.parsley.dsl.model.PartsSpecifications;
import org.eclipse.emf.parsley.dsl.model.ProposalCreator;
import org.eclipse.emf.parsley.dsl.model.ResourceManager;
import org.eclipse.emf.parsley.dsl.model.TableFeaturesProvider;
import org.eclipse.emf.parsley.dsl.model.TableLabelProvider;
import org.eclipse.emf.parsley.dsl.model.TableViewerContentProvider;
import org.eclipse.emf.parsley.dsl.model.ViewerContentProvider;
import org.eclipse.emf.parsley.dsl.services.EmfParsleyDslGrammarAccess;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.xtext.common.types.JvmVisibility;
import org.eclipse.xtext.xbase.ui.labeling.XbaseImages2;
import org.eclipse.xtext.xbase.ui.labeling.XbaseLabelProvider;

/**
 * Provides labels for a EObjects.
 * 
 * see http://www.eclipse.org/Xtext/documentation.html#labelProvider
 */
@SuppressWarnings("all")
public class EmfParsleyDslLabelProvider extends XbaseLabelProvider {
  @Inject
  private EmfParsleyDslGrammarAccess g;
  
  @Inject
  private XbaseImages2 images;
  
  @Inject
  public EmfParsleyDslLabelProvider(final AdapterFactoryLabelProvider delegate) {
    super(delegate);
  }
  
  public String text(final BindingsSpecification e) {
    return this.g.getBindingsSpecificationAccess().getBindingsKeyword_1().getValue();
  }
  
  public String text(final LabelProvider e) {
    return this.g.getLabelProviderAccess().getLabelProviderKeyword_1().getValue();
  }
  
  public String text(final TableLabelProvider e) {
    return this.g.getTableLabelProviderAccess().getTableLabelProviderKeyword_1().getValue();
  }
  
  public String text(final FeatureCaptionProvider e) {
    return this.g.getFeatureCaptionProviderAccess().getFeatureCaptionProviderKeyword_1().getValue();
  }
  
  public String text(final FormFeatureCaptionProvider e) {
    return this.g.getFormFeatureCaptionProviderAccess().getFormFeatureCaptionProviderKeyword_1().getValue();
  }
  
  public String text(final DialogFeatureCaptionProvider e) {
    return this.g.getDialogFeatureCaptionProviderAccess().getDialogFeatureCaptionProviderKeyword_1().getValue();
  }
  
  public String text(final FeaturesProvider e) {
    return this.g.getFeaturesProviderAccess().getFeaturesProviderKeyword_1().getValue();
  }
  
  public String text(final TableFeaturesProvider e) {
    return this.g.getTableFeaturesProviderAccess().getTableFeaturesProviderKeyword_1().getValue();
  }
  
  public String text(final FormControlFactory e) {
    return this.g.getFormControlFactoryAccess().getFormControlFactoryKeyword_1().getValue();
  }
  
  public String text(final DialogControlFactory e) {
    return this.g.getDialogControlFactoryAccess().getDialogControlFactoryKeyword_1().getValue();
  }
  
  public String text(final ProposalCreator e) {
    return this.g.getProposalCreatorAccess().getProposalsKeyword_1().getValue();
  }
  
  public String text(final MenuBuilder e) {
    return this.g.getMenuBuilderAccess().getMenuBuilderKeyword_1().getValue();
  }
  
  public String text(final Configurator e) {
    return this.g.getConfiguratorAccess().getConfiguratorKeyword_1().getValue();
  }
  
  public String text(final ViewerContentProvider e) {
    return this.g.getViewerContentProviderAccess().getViewerContentProviderKeyword_1().getValue();
  }
  
  public String text(final TableViewerContentProvider e) {
    return this.g.getTableViewerContentProviderAccess().getTableViewerContentProviderKeyword_1().getValue();
  }
  
  public String text(final PartsSpecifications e) {
    return this.g.getPartsSpecificationsAccess().getPartsKeyword_1().getValue();
  }
  
  public String text(final ResourceManager e) {
    return this.g.getResourceManagerAccess().getResourceManagerKeyword_1().getValue();
  }
  
  public ImageDescriptor image(final EObject e) {
    return this.images.forClass(JvmVisibility.PUBLIC, 0);
  }
}
